@@ -323,17 +323,6 @@ yPlot <- function(
     rows.use <- .which_rows(rows.use, data_frame)
     all.rows <- .all_rows(data_frame)
 
-    #Parse Title Defaults
-    main <- .leave_default_or_null(
-        main, default = paste0(unique(c(var, shape.by)), collapse = " and "))
-    xlab <- .leave_default_or_null(
-        xlab, default = group.by,
-        null.if = multivar.aes=="group" && length(var)>1)
-    ylab <- .leave_default_or_null(
-        ylab, default = var, null.if = identical(main,"var") || length(var)>1)
-    legend.title <- .leave_default_or_null(
-        legend.title, var, null.if = is.null(shape.by))
-
     ### Make data_frame and aesthetic target edits
     cols_use <- list(
         var = var,
@@ -343,17 +332,10 @@ yPlot <- function(
         split.by = split.by,
         group.aes = group.by
     )
-    if (group.by != color.by) {
-        cols_use$group.aes <- "group.aes"
-        data_frame$`group.aes` <- paste0(
-            as.character(data_frame[,group.by]),
-            ".-.",
-            as.character(data_frame[,color.by])
-        )
-    }
-    # Relabel/reorder for groups
+    # Relabel/reorder groups
     data_frame[,group.by] <-
         .rename_and_or_reorder(data_frame[,group.by], x.reorder, x.labels)
+    # Multivar adjustments
     if (length(var) > 1) {
         # (Only numeric data supported, handles color adjustment and rows.use subsetting)
         multi_out <- .multi_var_restructure(
@@ -380,6 +362,26 @@ yPlot <- function(
         # rows.use subsetting
         Target_data <- data_frame[rows.use,]
     }
+    # Interpret data groupings
+    if (cols_use$group.by != cols_use$color.by) {
+        cols_use$group.aes <- "__group.aes__"
+        Target_data$`__group.aes__` <- interaction(
+            Target_data[,cols_use$group.by], Target_data[,cols_use$color.by], sep = ".-."
+        )
+    }
+
+    # Parse Title Defaults
+    main <- .leave_default_or_null(
+        main, default = paste0(unique(var), collapse = " and "))
+    xlab <- .leave_default_or_null(
+        xlab, default = group.by,
+        null.if = multivar.aes=="group" && length(var)>1)
+    ylab <- .leave_default_or_null(
+        ylab, default = var, null.if = identical(main,"var") || length(var)>1)
+    legend.title <- .leave_default_or_null(
+        legend.title, color.by,
+        null.if = is.null(shape.by) || cols_use$color.by == "var.which")
+
     # Hover prep
     if (do.hover) {
         hover_exists <- hover.data[hover.data %in% colnames(Target_data)]
@@ -417,6 +419,7 @@ yPlot <- function(
             x.labels.rotate, do.hover, color.panel,
             colors, y.breaks, min, max)
     }
+
     # Extra tweaks
     if (!is.null(cols_use$split.by)) {
         p <- .add_splitting(
@@ -424,10 +427,9 @@ yPlot <- function(
     }
 
     # Get number of panels so that replicates of aesthetics can be generated if supplied for each line.
-    pp <- ggplot_build(p)
-    num.panels <- length(levels(pp$data[[1]]$PANEL))
-
     if (!is.null(add.line)) {
+        pp <- ggplot_build(p)
+        num.panels <- length(levels(pp$data[[1]]$PANEL))
         if(!("ridgeplot" %in% plots)) {
             p <- .add_yline(p, add.line, line.linetype, line.color, line.linewidth, line.opacity, num.panels)
         } else {
@@ -440,7 +442,7 @@ yPlot <- function(
     }
 
     if (do.hover) {
-        p <- .warn_or_apply_plotly(p, plots)
+        p <- .apply_plotly(p, plots)
     }
 
     # DONE. Return the plot +/- data
@@ -658,17 +660,12 @@ ridgeJitter <- function(..., plots = c("ridgeplot", "jitter")){ yPlot(..., plots
 boxPlot <- function(..., plots = c("boxplot","jitter")){ yPlot(..., plots = plots) }
 
 
-.warn_or_apply_plotly <- function(p, plots) {
-    if ("ridgeplot" %in% plots) {
-        warning("'do.hover = TRUE' request ignored because plotly does not support ridgeplots.")
+.apply_plotly <- function(p, plots) {
+    .error_if_no_plotly()
+    # Add hover.text to jitter, else just convert.
+    if ("jitter" %in% plots) {
+        plotly::ggplotly(p, tooltip = "text")
     } else {
-        .error_if_no_plotly()
-        # Add hover.text to jitter, else just convert.
-        if ("jitter" %in% plots) {
-            p <- plotly::ggplotly(p, tooltip = "text")
-        } else {
-            p <- plotly::ggplotly(p)
-        }
+        plotly::ggplotly(p)
     }
-    p
 }
