@@ -27,6 +27,12 @@ test_that("scatterPlot basic tweaks work", {
             df, "PC1", "PC2", cont,
             size = 10),
         "ggplot")
+    # Manual Check: size by variable
+    expect_s3_class(
+        scatterPlot(
+            df, "PC1", "PC2", cont,
+            size = cont2),
+        "ggplot")
     # Manuel Check: triangles
     expect_s3_class(
         scatterPlot(
@@ -40,6 +46,13 @@ test_that("scatterPlot basic tweaks work", {
             size = 5,
             opacity = 0.5),
         "ggplot")
+    # Manual check: opacity by variable
+    expect_s3_class(
+        scatterPlot(
+            df, "PC1", "PC2", cont,
+            size = 5,
+            opacity = cont2),
+        "ggplot")
 })
 
 test_that("scatterPlot main legend can be removed or adjusted, color and shape", {
@@ -409,6 +422,19 @@ test_that("scatterPlot lettering works", {
             do.letter = TRUE, size = 3,
             opacity = 0.5),
         "ggplot")
+    ### Manual Check: varying opacity by variable
+    expect_s3_class(
+        scatterPlot(
+            df, "PC1", "PC2", disc,
+            do.letter = TRUE, size = 3,
+            opacity = cont2),
+        "ggplot")
+    ### Manual Check: varying size by variable
+    expect_s3_class(
+        scatterPlot(
+            df, "PC1", "PC2", disc,
+            do.letter = TRUE, size = cont2),
+        "ggplot")
 })
 
 test_that("scatterPlot lettering request warns when conflicts with shape.by", {
